@@ -48,7 +48,7 @@ public sealed class BiDi : IAsyncDisposable
 
     public Network.NetworkModule Network => AsModule<Network.NetworkModule>();
 
-    internal Input.InputModule InputModule => AsModule<Input.InputModule>();
+    public Input.InputModule Input => AsModule<Input.InputModule>();
 
     public Script.ScriptModule Script => AsModule<Script.ScriptModule>();
 
@@ -60,11 +60,6 @@ public sealed class BiDi : IAsyncDisposable
 
     public Emulation.EmulationModule Emulation => AsModule<Emulation.EmulationModule>();
 
-    public Task<Session.StatusResult> StatusAsync()
-    {
-        return SessionModule.StatusAsync();
-    }
-
     public static async Task<BiDi> ConnectAsync(string url, BiDiOptions? options = null)
     {
         var bidi = new BiDi(url);
@@ -74,6 +69,16 @@ public sealed class BiDi : IAsyncDisposable
         return bidi;
     }
 
+    public Task<Session.StatusResult> StatusAsync(Session.StatusOptions? options = null)
+    {
+        return SessionModule.StatusAsync(options);
+    }
+
+    public Task<Session.NewResult> NewAsync(Session.CapabilitiesRequest capabilities, Session.NewOptions? options = null)
+    {
+        return SessionModule.NewAsync(capabilities, options);
+    }
+
     public Task EndAsync(Session.EndOptions? options = null)
     {
         return SessionModule.EndAsync(options);
