@@ -69,7 +69,7 @@ public sealed record BrowsingContext
     public BrowsingContextStorageModule Storage => _storageModule ?? Interlocked.CompareExchange(ref _storageModule, new BrowsingContextStorageModule(this, BiDi.Storage), null) ?? _storageModule;
 
     [JsonIgnore]
-    public BrowsingContextInputModule Input => _inputModule ?? Interlocked.CompareExchange(ref _inputModule, new BrowsingContextInputModule(this, BiDi.InputModule), null) ?? _inputModule;
+    public BrowsingContextInputModule Input => _inputModule ?? Interlocked.CompareExchange(ref _inputModule, new BrowsingContextInputModule(this, BiDi.Input), null) ?? _inputModule;
 
     public Task<NavigateResult> NavigateAsync(string url, NavigateOptions? options = null)
     {
@@ -133,102 +133,222 @@ public sealed record BrowsingContext
 
     public Task<Subscription> OnNavigationStartedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationStartedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationStartedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationStartedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationStartedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationStartedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnFragmentNavigatedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnFragmentNavigatedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnFragmentNavigatedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnFragmentNavigatedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnFragmentNavigatedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnFragmentNavigatedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnHistoryUpdatedAsync(Func<HistoryUpdatedEventArgs, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnHistoryUpdatedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnHistoryUpdatedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnHistoryUpdatedAsync(Action<HistoryUpdatedEventArgs> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnHistoryUpdatedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnHistoryUpdatedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDomContentLoadedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDomContentLoadedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDomContentLoadedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDomContentLoadedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDomContentLoadedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDomContentLoadedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnLoadAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnLoadAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnLoadAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnLoadAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnLoadAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnLoadAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDownloadWillBeginAsync(Action<DownloadWillBeginEventArgs> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDownloadWillBeginAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDownloadWillBeginAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDownloadWillBeginAsync(Func<DownloadWillBeginEventArgs, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDownloadWillBeginAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDownloadWillBeginAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDownloadEndAsync(Action<DownloadEndEventArgs> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDownloadEndAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDownloadEndAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnDownloadEndAsync(Func<DownloadEndEventArgs, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnDownloadEndAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnDownloadEndAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationAbortedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationAbortedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationAbortedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationAbortedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationAbortedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationAbortedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationFailedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationFailedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationFailedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationFailedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationFailedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationFailedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationCommittedAsync(Action<NavigationInfo> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationCommittedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationCommittedAsync(e =>
+        {
+            if (Equals(e.Context))
+            {
+                handler(e);
+            }
+        }, options.WithContext(this));
     }
 
     public Task<Subscription> OnNavigationCommittedAsync(Func<NavigationInfo, Task> handler, ContextSubscriptionOptions? options = null)
     {
-        return BiDi.BrowsingContext.OnNavigationCommittedAsync(handler, options.WithContext(this));
+        return BiDi.BrowsingContext.OnNavigationCommittedAsync(async e =>
+        {
+            if (Equals(e.Context))
+            {
+                await handler(e).ConfigureAwait(false);
+            }
+        }, options.WithContext(this));
     }
 
     public bool Equals(BrowsingContext? other)
@@ -241,7 +361,6 @@ public sealed record BrowsingContext
         return Id is not null ? StringComparer.Ordinal.GetHashCode(Id) : 0;
     }
 
-    // Includes Id only for brevity
     private bool PrintMembers(StringBuilder builder)
     {
         builder.Append($"Id = {Id}");
