@@ -18,30 +18,7 @@
 // </copyright>
 
 using System.Collections.Generic;
-using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.Script;
 
-public sealed record NodeProperties(long NodeType, long ChildNodeCount)
-{
-    [JsonInclude]
-    public IReadOnlyDictionary<string, string>? Attributes { get; internal set; }
-
-    [JsonInclude]
-    public IReadOnlyList<NodeRemoteValue>? Children { get; internal set; }
-
-    [JsonInclude]
-    public string? LocalName { get; internal set; }
-
-    [JsonInclude]
-    public Mode? Mode { get; internal set; }
-
-    [JsonInclude]
-    public string? NamespaceUri { get; internal set; }
-
-    [JsonInclude]
-    public string? NodeValue { get; internal set; }
-
-    [JsonInclude]
-    public NodeRemoteValue? ShadowRoot { get; internal set; }
-}
+public sealed record NodeProperties(long NodeType, long ChildNodeCount, IReadOnlyDictionary<string, string>? Attributes, IReadOnlyList<NodeRemoteValue>? Children, string? LocalName, Mode? Mode, string? NamespaceUri, string? NodeValue, NodeRemoteValue? ShadowRoot);
