@@ -17,7 +17,6 @@
 // under the License.
 // </copyright>
 
-using OpenQA.Selenium.BiDi.Communication;
 using System;
 using System.Collections.Generic;
 using System.Threading.Tasks;
@@ -26,20 +25,22 @@ namespace OpenQA.Selenium.BiDi;
 
 public class Subscription : IAsyncDisposable
 {
-    private readonly Session.Subscription _subscription;
     private readonly Broker _broker;
-    private readonly Communication.EventHandler _eventHandler;
 
-    internal Subscription(Session.Subscription subscription, Broker broker, Communication.EventHandler eventHandler)
+    internal Subscription(Session.Subscription subscription, Broker broker, EventHandler eventHandler)
     {
-        _subscription = subscription;
+        SubscriptionId = subscription;
         _broker = broker;
-        _eventHandler = eventHandler;
+        EventHandler = eventHandler;
     }
 
+    internal Session.Subscription SubscriptionId { get; }
+
+    internal EventHandler EventHandler { get; }
+
     public async Task UnsubscribeAsync()
     {
-        await _broker.UnsubscribeAsync(_subscription, _eventHandler).ConfigureAwait(false);
+        await _broker.UnsubscribeAsync(this).ConfigureAwait(false);
     }
 
     public async ValueTask DisposeAsync()
@@ -50,15 +51,25 @@ public class Subscription : IAsyncDisposable
 
 public class SubscriptionOptions
 {
+    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
+
+    public IEnumerable<Browser.UserContext>? UserContexts { get; set; }
+
     public TimeSpan? Timeout { get; set; }
 }
 
-public class BrowsingContextsSubscriptionOptions : SubscriptionOptions
+public class ContextSubscriptionOptions
 {
-    public BrowsingContextsSubscriptionOptions(SubscriptionOptions? options)
+    public TimeSpan? Timeout { get; set; }
+}
+
+internal static class ContextSubscriptionOptionsExtensions
+{
+    // Converts ContextSubscriptionOptions to SubscriptionOptions with the specified context.
+    // Deeply copying other properties as needed.
+    public static SubscriptionOptions WithContext(this ContextSubscriptionOptions? options, BrowsingContext.BrowsingContext context) => new()
     {
-        Timeout = options?.Timeout;
-    }
-
-    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
+        Contexts = [context],
+        Timeout = options?.Timeout
+    };
 }
