@@ -17,6 +17,8 @@
 // under the License.
 // </copyright>
 
+using System;
+using System.Diagnostics;
 using System.Globalization;
 using System.IO;
 using System.Reflection;
@@ -27,7 +29,7 @@ namespace OpenQA.Selenium.Internal;
 /// <summary>
 /// Encapsulates methods for finding and extracting WebDriver resources.
 /// </summary>
-internal static class ResourceUtilities
+internal static partial class ResourceUtilities
 {
     private static string? productVersion;
     private static string? platformFamily;
@@ -114,6 +116,40 @@ internal static class ResourceUtilities
 
     private static string GetPlatformString()
     {
+#if NET462
+        // Unfortunately, detecting the currently running platform isn't as
+        // straightforward as you might hope.
+        // See: http://mono.wikia.com/wiki/Detecting_the_execution_platform
+        // and https://msdn.microsoft.com/en-us/library/3a8hyw88(v=vs.110).aspx
+        string platformName = "unknown";
+        const int PlatformMonoUnixValue = 128;
+        PlatformID platformId = Environment.OSVersion.Platform;
+        if (platformId == PlatformID.Unix || platformId == PlatformID.MacOSX || (int)platformId == PlatformMonoUnixValue)
+        {
+            using (Process unameProcess = new Process())
+            {
+                unameProcess.StartInfo.FileName = "uname";
+                unameProcess.StartInfo.UseShellExecute = false;
+                unameProcess.StartInfo.RedirectStandardOutput = true;
+                unameProcess.Start();
+                unameProcess.WaitForExit(1000);
+                string output = unameProcess.StandardOutput.ReadToEnd();
+                if (output.ToLowerInvariant().StartsWith("darwin"))
+                {
+                    platformName = "mac";
+                }
+                else
+                {
+                    platformName = "linux";
+                }
+            }
+        }
+        else if (platformId == PlatformID.Win32NT || platformId == PlatformID.Win32S || platformId == PlatformID.Win32Windows || platformId == PlatformID.WinCE)
+        {
+            platformName = "windows";
+        }
+        return platformName;
+#else
         if (RuntimeInformation.IsOSPlatform(OSPlatform.Windows))
         {
             return "windows";
@@ -130,5 +166,6 @@ internal static class ResourceUtilities
         {
             return "unknown";
         }
+#endif
     }
 }
