@@ -23,7 +23,6 @@ using System;
 using System.Collections.Generic;
 using System.Diagnostics.CodeAnalysis;
 using System.Globalization;
-using System.IO;
 using System.Linq;
 using System.Text.Json;
 using System.Threading.Tasks;
@@ -141,7 +140,7 @@ public class JavaScriptEngine : IJavaScriptEngine
     public async Task EnableDomMutationMonitoring()
     {
         // Execute the script to have it enabled on the currently loaded page.
-        string script = GetMutationListenerScript();
+        string script = ResourceUtilities.MutationListenerAtom;
         await this.session.Value.Domains.JavaScript.Evaluate(script).ConfigureAwait(false);
 
         await this.AddScriptCallbackBinding(MonitorBindingName).ConfigureAwait(false);
@@ -165,7 +164,7 @@ public class JavaScriptEngine : IJavaScriptEngine
     /// <param name="script">The JavaScript to be loaded on every page.</param>
     /// <returns>A task containing an <see cref="InitializationScript"/> object representing the script to be loaded on each page.</returns>
     /// <exception cref="ArgumentNullException">If <paramref name="scriptName"/> or <paramref name="script"/> are <see langword="null"/>.</exception>
-    public async Task<InitializationScript> AddInitializationScript(string scriptName, string script)
+    public async Task<InitializationScript> AddInitializationScript(string scriptName, [StringSyntax(StringSyntaxConstants.JavaScript)] string script)
     {
         if (scriptName is null)
         {
@@ -234,7 +233,7 @@ public class JavaScriptEngine : IJavaScriptEngine
     /// <param name="script">The JavaScript to pin</param>
     /// <returns>A task containing a <see cref="PinnedScript"/> object to use to execute the script.</returns>
     /// <exception cref="ArgumentNullException">If <paramref name="script"/> is <see langword="null"/>.</exception>
-    public async Task<PinnedScript> PinScript(string script)
+    public async Task<PinnedScript> PinScript([StringSyntax(StringSyntaxConstants.JavaScript)] string script)
     {
         if (script == null)
         {
@@ -408,20 +407,6 @@ public class JavaScriptEngine : IJavaScriptEngine
         }
     }
 
-    private static string GetMutationListenerScript()
-    {
-        string listenerScript = string.Empty;
-        using (Stream resourceStream = ResourceUtilities.GetResourceStream("mutation-listener.js", "mutation-listener.js"))
-        {
-            using (StreamReader resourceReader = new StreamReader(resourceStream))
-            {
-                listenerScript = resourceReader.ReadToEnd();
-            }
-        }
-
-        return listenerScript;
-    }
-
     private void OnScriptBindingCalled(object? sender, BindingCalledEventArgs e)
     {
         if (e.Name == MonitorBindingName)
