@@ -24,7 +24,7 @@ namespace OpenQA.Selenium;
 /// <summary>
 /// Provides a mechanism for maintaining a session for a test
 /// </summary>
-public class SessionId
+public class SessionId : IEquatable<SessionId>
 {
     private readonly string sessionOpaqueKey;
 
@@ -63,6 +63,16 @@ public class SessionId
     /// <returns><see langword="true"/> if the values are equal; otherwise, <see langword="false"/>.</returns>
     public override bool Equals(object? obj)
     {
-        return obj is SessionId otherSession && this.sessionOpaqueKey.Equals(otherSession.sessionOpaqueKey);
+        return Equals(obj as SessionId);
+    }
+
+    /// <summary>
+    /// Indicates whether the current session ID value is the same as <paramref name="other"/>.
+    /// </summary>
+    /// <param name="other">The session to compare to.</param>
+    /// <returns><see langword="true"/> if the values are equal; otherwise, <see langword="false"/>.</returns>
+    public bool Equals(SessionId? other)
+    {
+        return other is not null && string.Equals(this.sessionOpaqueKey, other.sessionOpaqueKey);
     }
 }
