@@ -18,18 +18,10 @@
 // </copyright>
 
 using NUnit.Framework;
-using OpenQA.Selenium.Environment;
-using System.Threading.Tasks;
 
 namespace OpenQA.Selenium.Chrome;
 
 [TestFixture]
 public class ChromeSpecificTests : DriverTestFixture
 {
-    [OneTimeTearDown]
-    public async Task RunAfterAnyTestsAsync()
-    {
-        EnvironmentManager.Instance.CloseCurrentDriver();
-        await EnvironmentManager.Instance.WebServer.StopAsync();
-    }
 }
