@@ -23,7 +23,7 @@ using System.Threading.Tasks;
 
 namespace OpenQA.Selenium.BiDi.Script;
 
-class CallFunctionParameterTest : BiDiTestFixture
+internal class CallFunctionParameterTest : BiDiTestFixture
 {
     [Test]
     public async Task CanCallFunctionWithDeclaration()
