@@ -18,7 +18,6 @@
 // </copyright>
 
 using NUnit.Framework;
-using OpenQA.Selenium.BiDi.Modules.Script;
 using System;
 using System.Collections.Generic;
 using System.Collections.Immutable;
@@ -26,7 +25,7 @@ using System.Linq;
 
 namespace OpenQA.Selenium.BiDi.Script;
 
-class LocalValueConversionTests
+internal class LocalValueConversionTests
 {
     [Test]
     public void CanConvertNullBoolToLocalValue()
