@@ -28,20 +28,15 @@ using System;
 namespace OpenQA.Selenium;
 
 [AttributeUsage(AttributeTargets.Method | AttributeTargets.Class, AllowMultiple = true)]
-public class IgnoreTargetAttribute : NUnitAttribute, IApplyToTest
+public class IgnoreTargetAttribute(string target) : NUnitAttribute, IApplyToTest
 {
-    public IgnoreTargetAttribute(string target)
-    {
-        this.Value = target.ToLower();
-    }
-
     public IgnoreTargetAttribute(string target, string reason)
         : this(target)
     {
         this.Reason = reason;
     }
 
-    public string Value { get; }
+    public string Value { get; } = target.ToLower();
 
     public string Reason { get; } = string.Empty;
 
