@@ -25,39 +25,29 @@ namespace OpenQA.Selenium;
 
 public class NeedsFreshDriverAttribute : TestActionAttribute
 {
-    private bool isCreatedBeforeTest = false;
-    private bool isCreatedAfterTest = false;
+    public bool IsCreatedBeforeTest { get; set; } = false;
 
-    public bool IsCreatedBeforeTest
-    {
-        get { return isCreatedBeforeTest; }
-        set { isCreatedBeforeTest = value; }
-    }
-
-    public bool IsCreatedAfterTest
-    {
-        get { return isCreatedAfterTest; }
-        set { isCreatedAfterTest = value; }
-    }
+    public bool IsCreatedAfterTest { get; set; } = false;
 
     public override void BeforeTest(ITest test)
     {
-        DriverTestFixture fixtureInstance = test.Fixture as DriverTestFixture;
-        if (fixtureInstance != null && this.isCreatedBeforeTest)
+        if (test.Fixture is DriverTestFixture fixtureInstance && this.IsCreatedBeforeTest)
         {
             EnvironmentManager.Instance.CreateFreshDriver();
-            fixtureInstance.DriverInstance = EnvironmentManager.Instance.GetCurrentDriver();
+            fixtureInstance.driver = EnvironmentManager.Instance.GetCurrentDriver();
         }
+
         base.BeforeTest(test);
     }
 
     public override void AfterTest(ITest test)
     {
-        DriverTestFixture fixtureInstance = test.Fixture as DriverTestFixture;
-        if (fixtureInstance != null && this.isCreatedAfterTest)
+        if (test.Fixture is DriverTestFixture fixtureInstance && this.IsCreatedAfterTest)
         {
             EnvironmentManager.Instance.CreateFreshDriver();
-            fixtureInstance.DriverInstance = EnvironmentManager.Instance.GetCurrentDriver();
+            fixtureInstance.driver = EnvironmentManager.Instance.GetCurrentDriver();
         }
+
+        base.AfterTest(test);
     }
 }
