@@ -18,14 +18,14 @@
 // </copyright>
 
 using NUnit.Framework;
+using OpenQA.Selenium;
 using OpenQA.Selenium.Environment;
 using System.Threading.Tasks;
 
-namespace OpenQA.Selenium.Remote;
-
 [SetUpFixture]
-// Outside a namespace to affect the entire assembly
-public class MySetUpClass
+#pragma warning disable // Outside a namespace to affect the entire assembly
+public class AssemblyTeardown
+#pragma warning restore
 {
     [OneTimeSetUp]
     public async Task RunBeforeAnyTestAsync()
