@@ -18,11 +18,9 @@
 package org.openqa.selenium;
 
 import java.util.Objects;
-import org.jspecify.annotations.NullMarked;
 import org.jspecify.annotations.Nullable;
 
 /** Similar to Point - implement locally to avoid depending on GWT. */
-@NullMarked
 public class Dimension {
   public final int width;
   public final int height;
