@@ -17,10 +17,8 @@
 
 package org.openqa.selenium;
 
-import org.jspecify.annotations.NullMarked;
 import org.jspecify.annotations.Nullable;
 
-@NullMarked
 public enum PageLoadStrategy {
   NONE("none"),
   EAGER("eager"),
