@@ -17,21 +17,24 @@
 
 package org.openqa.selenium.grid.commands;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static java.util.Objects.requireNonNull;
+
 import com.beust.jcommander.JCommander;
 import com.beust.jcommander.ParameterException;
 import com.beust.jcommander.internal.DefaultConsole;
 import com.google.auto.service.AutoService;
-import com.google.common.io.Resources;
 import java.io.BufferedReader;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.PrintStream;
 import java.io.PrintWriter;
 import java.io.StringReader;
 import java.io.UncheckedIOException;
-import java.nio.charset.StandardCharsets;
 import java.util.Collections;
 import java.util.Set;
 import java.util.regex.Pattern;
+import org.jspecify.annotations.NonNull;
 import org.openqa.selenium.cli.CliCommand;
 import org.openqa.selenium.cli.WrappedPrintWriter;
 import org.openqa.selenium.grid.config.Role;
@@ -130,8 +133,7 @@ public class InfoCommand implements CliCommand {
   }
 
   private String readContent(String path) throws IOException {
-    String unformattedText =
-        Resources.toString(Resources.getResource(path), StandardCharsets.UTF_8);
+    String unformattedText = unformattedText(path);
     StringBuilder formattedText = new StringBuilder();
     try (BufferedReader reader = new BufferedReader(new StringReader(unformattedText))) {
       boolean inCode = false;
@@ -161,4 +163,12 @@ public class InfoCommand implements CliCommand {
 
     return formattedText.toString();
   }
+
+  @NonNull
+  private String unformattedText(String path) throws IOException {
+    try (InputStream in = getClass().getClassLoader().getResourceAsStream(path)) {
+      requireNonNull(in, () -> "Resource is not found in classpath: " + path);
+      return new String(in.readAllBytes(), UTF_8);
+    }
+  }
 }
