@@ -21,7 +21,6 @@ import static org.openqa.selenium.grid.data.Availability.DOWN;
 import static org.openqa.selenium.grid.data.Availability.DRAINING;
 import static org.openqa.selenium.grid.data.Availability.UP;
 
-import com.google.common.collect.ImmutableSet;
 import java.time.Instant;
 import java.util.Collections;
 import java.util.HashMap;
@@ -338,13 +337,16 @@ public class LocalGridModel extends GridModel {
       }
 
       Optional<Slot> maybeSlot =
-          node.getSlots().stream().filter(slot -> slotId.equals(slot.getId())).findFirst();
+          node.getSlots().stream()
+              .filter(slot -> slotId.equals(slot.getId()))
+              .filter(slot -> slot.getSession() == null)
+              .findFirst();
 
-      if (!maybeSlot.isPresent()) {
-        LOG.warning(
+      if (maybeSlot.isEmpty()) {
+        LOG.fine(
             String.format(
-                "Asked to reserve slot on node %s, but no slot with id %s found",
-                node.getNodeId(), slotId));
+                "Asked to reserve slot %s on node %s, but slot not found or already reserved",
+                slotId, node.getNodeId()));
         return false;
       }
 
@@ -360,7 +362,7 @@ public class LocalGridModel extends GridModel {
     Lock readLock = this.lock.readLock();
     readLock.lock();
     try {
-      return ImmutableSet.copyOf(nodes);
+      return Set.copyOf(nodes);
     } finally {
       readLock.unlock();
     }
@@ -438,7 +440,7 @@ public class LocalGridModel extends GridModel {
       Optional<Slot> maybeSlot =
           node.getSlots().stream().filter(slot -> slotId.equals(slot.getId())).findFirst();
 
-      if (!maybeSlot.isPresent()) {
+      if (maybeSlot.isEmpty()) {
         LOG.warning("Grid model and reality have diverged. Unable to find slot " + slotId);
         return;
       }
