@@ -20,11 +20,6 @@ package org.openqa.selenium.grid.node.config;
 import static org.openqa.selenium.remote.CapabilityType.ENABLE_DOWNLOADS;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.HashMultimap;
-import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.ImmutableMultimap;
-import com.google.common.collect.ImmutableSet;
-import com.google.common.collect.Multimap;
 import java.io.File;
 import java.io.StringReader;
 import java.lang.reflect.Method;
@@ -33,15 +28,16 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.time.Duration;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.Comparator;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Optional;
 import java.util.ServiceLoader;
+import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Function;
 import java.util.logging.Level;
@@ -56,18 +52,20 @@ import org.openqa.selenium.Platform;
 import org.openqa.selenium.SessionNotCreatedException;
 import org.openqa.selenium.WebDriver;
 import org.openqa.selenium.WebDriverException;
-import org.openqa.selenium.WebDriverInfo;
 import org.openqa.selenium.grid.config.Config;
 import org.openqa.selenium.grid.config.ConfigException;
 import org.openqa.selenium.grid.data.SlotMatcher;
 import org.openqa.selenium.grid.node.Node;
 import org.openqa.selenium.grid.node.SessionFactory;
+import org.openqa.selenium.internal.Multimap;
 import org.openqa.selenium.internal.Require;
 import org.openqa.selenium.json.Json;
 import org.openqa.selenium.json.JsonOutput;
 import org.openqa.selenium.net.NetworkUtils;
 import org.openqa.selenium.net.Urls;
 import org.openqa.selenium.remote.Browser;
+import org.openqa.selenium.remote.WebDriverInfo;
+import org.openqa.selenium.remote.http.ClientConfig;
 import org.openqa.selenium.remote.service.DriverService;
 
 public class NodeOptions {
@@ -77,6 +75,7 @@ public class NodeOptions {
   public static final int DEFAULT_SESSION_TIMEOUT = 300;
   public static final int DEFAULT_DRAIN_AFTER_SESSION_COUNT = 0;
   public static final int DEFAULT_CONNECTION_LIMIT = 10;
+  public static final int DEFAULT_NODE_DOWN_FAILURE_THRESHOLD = 0;
   public static final boolean DEFAULT_DELETE_SESSION_ON_UI = false;
   public static final boolean DEFAULT_ENABLE_CDP = true;
   public static final boolean DEFAULT_ENABLE_BIDI = true;
@@ -85,7 +84,7 @@ public class NodeOptions {
   static final boolean DEFAULT_USE_SELENIUM_MANAGER = false;
   static final boolean OVERRIDE_MAX_SESSIONS = false;
   static final List<String> DEFAULT_VNC_ENV_VARS =
-      Arrays.asList("SE_START_XVFB", "SE_START_VNC", "SE_START_NO_VNC");
+      List.of("SE_START_XVFB", "SE_START_VNC", "SE_START_NO_VNC");
   static final int DEFAULT_NO_VNC_PORT = 7900;
   static final int DEFAULT_REGISTER_CYCLE = 10;
   static final int DEFAULT_REGISTER_PERIOD = 120;
@@ -95,8 +94,8 @@ public class NodeOptions {
   private static final Logger LOG = Logger.getLogger(NodeOptions.class.getName());
   private static final Json JSON = new Json();
   private static final Platform CURRENT_PLATFORM = Platform.getCurrent();
-  private static final ImmutableSet<String> SINGLE_SESSION_DRIVERS =
-      ImmutableSet.of("safari", "safari technology preview");
+  private static final Set<String> SINGLE_SESSION_DRIVERS =
+      Set.of("safari", "safari technology preview");
 
   private final Config config;
   private final AtomicBoolean vncEnabled = new AtomicBoolean();
@@ -249,15 +248,14 @@ public class NodeOptions {
     Map<WebDriverInfo, Collection<SessionFactory>> allDrivers =
         discoverDrivers(maxSessions, factoryFactory);
 
-    ImmutableMultimap.Builder<Capabilities, SessionFactory> sessionFactories =
-        ImmutableMultimap.builder();
+    Multimap<Capabilities, SessionFactory> sessionFactories = new Multimap<>();
 
     addDriverFactoriesFromConfig(sessionFactories);
     addDriverConfigs(factoryFactory, sessionFactories, maxSessions);
     addSpecificDrivers(allDrivers, sessionFactories);
     addDetectedDrivers(allDrivers, sessionFactories);
 
-    return sessionFactories.build().asMap();
+    return sessionFactories.asMap();
   }
 
   public int getMaxSessions() {
@@ -280,6 +278,12 @@ public class NodeOptions {
     return connectionLimit;
   }
 
+  public int getNodeDownFailureThreshold() {
+    return config
+        .getInt(NODE_SECTION, "node-down-failure-threshold")
+        .orElse(DEFAULT_NODE_DOWN_FAILURE_THRESHOLD);
+  }
+
   public Duration getSessionTimeout() {
     // If the user sets 10s or less, we default to 10s.
     int seconds =
@@ -333,7 +337,7 @@ public class NodeOptions {
   }
 
   private void addDriverFactoriesFromConfig(
-      ImmutableMultimap.Builder<Capabilities, SessionFactory> sessionFactories) {
+      Multimap<Capabilities, SessionFactory> sessionFactories) {
     config
         .getAll(NODE_SECTION, "driver-factories")
         .ifPresent(
@@ -392,10 +396,10 @@ public class NodeOptions {
 
   private void addDriverConfigs(
       Function<ImmutableCapabilities, Collection<SessionFactory>> factoryFactory,
-      ImmutableMultimap.Builder<Capabilities, SessionFactory> sessionFactories,
+      Multimap<Capabilities, SessionFactory> sessionFactories,
       int maxSessions) {
 
-    Multimap<WebDriverInfo, SessionFactory> driverConfigs = HashMultimap.create();
+    Map<WebDriverInfo, Collection<SessionFactory>> driverConfigs = new HashMap<>();
 
     // get all driver configuration settings
     config
@@ -523,14 +527,17 @@ public class NodeOptions {
                                   new ImmutableCapabilities(stereotype);
                               int maxDriverSessions = getDriverMaxSessions(info, driverMaxSessions);
                               for (int i = 0; i < maxDriverSessions; i++) {
-                                driverConfigs.putAll(
-                                    driverInfoConfig, factoryFactory.apply(immutable));
+                                Collection<SessionFactory> factories =
+                                    factoryFactory.apply(immutable);
+                                driverConfigs
+                                    .computeIfAbsent(driverInfoConfig, __ -> new HashSet<>())
+                                    .addAll(factories);
                               }
                             });
                   });
             });
 
-    driverConfigs.asMap().entrySet().stream()
+    driverConfigs.entrySet().stream()
         .peek(this::report)
         .forEach(
             entry ->
@@ -540,7 +547,7 @@ public class NodeOptions {
 
   private void addDetectedDrivers(
       Map<WebDriverInfo, Collection<SessionFactory>> allDrivers,
-      ImmutableMultimap.Builder<Capabilities, SessionFactory> sessionFactories) {
+      Multimap<Capabilities, SessionFactory> sessionFactories) {
     if (!config.getBool(NODE_SECTION, "detect-drivers").orElse(DEFAULT_DETECT_DRIVERS)) {
       return;
     }
@@ -559,7 +566,7 @@ public class NodeOptions {
               sessionFactories.putAll(capabilities, entry.getValue());
             });
 
-    if (sessionFactories.build().isEmpty()) {
+    if (sessionFactories.isEmpty()) {
       String logMessage = "No drivers have been configured or have been found on PATH";
       LOG.warning(logMessage);
       throw new ConfigException(logMessage);
@@ -568,7 +575,7 @@ public class NodeOptions {
 
   private void addSpecificDrivers(
       Map<WebDriverInfo, Collection<SessionFactory>> allDrivers,
-      ImmutableMultimap.Builder<Capabilities, SessionFactory> sessionFactories) {
+      Multimap<Capabilities, SessionFactory> sessionFactories) {
     if (config.getAll(NODE_SECTION, "driver-implementation").isEmpty()) {
       return;
     }
@@ -625,7 +632,7 @@ public class NodeOptions {
       int maxSessions, Function<ImmutableCapabilities, Collection<SessionFactory>> factoryFactory) {
 
     if (!config.getBool(NODE_SECTION, "detect-drivers").orElse(DEFAULT_DETECT_DRIVERS)) {
-      return ImmutableMap.of();
+      return Map.of();
     }
 
     // We don't expect duplicates, but they're fine
@@ -656,7 +663,7 @@ public class NodeOptions {
     List<DriverService.Builder<?, ?>> builders = new ArrayList<>();
     ServiceLoader.load(DriverService.Builder.class).forEach(builders::add);
 
-    Multimap<WebDriverInfo, SessionFactory> toReturn = HashMultimap.create();
+    Multimap<WebDriverInfo, SessionFactory> toReturn = new Multimap<>();
     infos.forEach(
         info -> {
           Capabilities caps = enhanceStereotype(info.getCanonicalCapabilities());
@@ -668,7 +675,8 @@ public class NodeOptions {
                     ImmutableCapabilities immutable = new ImmutableCapabilities(caps);
                     int maxDriverSessions = getDriverMaxSessions(info, maxSessions);
                     for (int i = 0; i < maxDriverSessions; i++) {
-                      toReturn.putAll(info, factoryFactory.apply(immutable));
+                      Collection<SessionFactory> factories = factoryFactory.apply(immutable);
+                      toReturn.putAll(info, factories);
                     }
                   });
         });
@@ -720,7 +728,7 @@ public class NodeOptions {
       }
 
       @Override
-      public Optional<WebDriver> createDriver(Capabilities capabilities)
+      public Optional<WebDriver> createDriver(Capabilities capabilities, ClientConfig clientConfig)
           throws SessionNotCreatedException {
         return Optional.empty();
       }
