@@ -17,13 +17,12 @@
 
 package org.openqa.selenium.grid.node.local;
 
-import static com.google.common.collect.ImmutableSet.toImmutableSet;
 import static java.nio.file.Files.readAttributes;
 import static java.time.ZoneOffset.UTC;
 import static java.time.format.DateTimeFormatter.RFC_1123_DATE_TIME;
-import static java.util.Arrays.asList;
 import static java.util.Locale.US;
 import static java.util.Objects.requireNonNullElseGet;
+import static java.util.stream.Collectors.toUnmodifiableSet;
 import static org.openqa.selenium.HasDownloads.DownloadedFile;
 import static org.openqa.selenium.concurrent.ExecutorServices.shutdownGracefully;
 import static org.openqa.selenium.grid.data.Availability.DOWN;
@@ -44,7 +43,6 @@ import com.github.benmanes.caffeine.cache.Caffeine;
 import com.github.benmanes.caffeine.cache.RemovalCause;
 import com.github.benmanes.caffeine.cache.Ticker;
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.ImmutableList;
 import com.google.common.net.MediaType;
 import java.io.Closeable;
 import java.io.File;
@@ -53,12 +51,14 @@ import java.io.Serializable;
 import java.io.UncheckedIOException;
 import java.net.URI;
 import java.net.URISyntaxException;
+import java.nio.file.NoSuchFileException;
 import java.nio.file.attribute.BasicFileAttributes;
 import java.nio.file.attribute.FileTime;
 import java.time.Clock;
 import java.time.Duration;
 import java.time.Instant;
 import java.time.format.DateTimeFormatter;
+import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
@@ -155,6 +155,11 @@ public class LocalNode extends Node implements Closeable {
   private final Cache<SessionId, TemporaryFilesystem> downloadsTempFileSystem;
   private final AtomicInteger pendingSessions = new AtomicInteger();
   private final AtomicInteger sessionCount = new AtomicInteger();
+  // Tracks sessions that are reserved (pending creation) or active, used for maxSessionCount check
+  private final AtomicInteger reservedOrActiveSessionCount = new AtomicInteger();
+  // Tracks consecutive session creation failures to mark node DOWN if threshold exceeded
+  private final AtomicInteger consecutiveSessionFailures = new AtomicInteger();
+  private final int nodeDownFailureThreshold;
   private final Runnable shutdown;
   private final ReadWriteLock drainLock = new ReentrantReadWriteLock();
 
@@ -174,7 +179,8 @@ public class LocalNode extends Node implements Closeable {
       List<SessionSlot> factories,
       Secret registrationSecret,
       boolean managedDownloadsEnabled,
-      int connectionLimitPerSession) {
+      int connectionLimitPerSession,
+      int nodeDownFailureThreshold) {
     super(
         tracer,
         new NodeId(UUID.randomUUID()),
@@ -189,7 +195,7 @@ public class LocalNode extends Node implements Closeable {
     this.maxSessionCount =
         Math.min(Require.positive("Max session count", maxSessionCount), factories.size());
     this.heartbeatPeriod = heartbeatPeriod;
-    this.factories = ImmutableList.copyOf(factories);
+    this.factories = List.copyOf(factories);
     Require.nonNull("Registration secret", registrationSecret);
     this.configuredSessionCount = drainAfterSessionCount;
     this.drainAfterSessions = this.configuredSessionCount > 0;
@@ -198,6 +204,8 @@ public class LocalNode extends Node implements Closeable {
     this.bidiEnabled = bidiEnabled;
     this.managedDownloadsEnabled = managedDownloadsEnabled;
     this.connectionLimitPerSession = connectionLimitPerSession;
+    // Use 0 to disable the failure threshold feature (unlimited retries)
+    this.nodeDownFailureThreshold = nodeDownFailureThreshold;
 
     this.healthCheck =
         healthCheck == null
@@ -362,6 +370,8 @@ public class LocalNode extends Node implements Closeable {
         }
         // Attempt to stop the session with the appropriate reason
         slot.stop(closeReason);
+        // Decrement the reserved/active session counter
+        reservedOrActiveSessionCount.decrementAndGet();
         // Decrement pending sessions if Node is draining
         if (this.isDraining()) {
           int done = pendingSessions.decrementAndGet();
@@ -407,6 +417,10 @@ public class LocalNode extends Node implements Closeable {
 
   @ManagedAttribute(name = "Status")
   public Availability getAvailability() {
+    if (nodeDownFailureThreshold > 0
+        && consecutiveSessionFailures.get() >= nodeDownFailureThreshold) {
+      return DOWN;
+    }
     return isDraining() ? DRAINING : UP;
   }
 
@@ -426,6 +440,26 @@ public class LocalNode extends Node implements Closeable {
     return inUse / (float) maxSessionCount * 100f;
   }
 
+  @ManagedAttribute(name = "ConsecutiveSessionFailures")
+  public int getConsecutiveSessionFailures() {
+    return consecutiveSessionFailures.get();
+  }
+
+  /**
+   * Resets the consecutive session creation failure counter. This can be used to recover a node
+   * that was marked as DOWN due to exceeding the failure threshold, for example after external
+   * intervention has resolved the underlying issue.
+   */
+  public void resetConsecutiveSessionFailures() {
+    int previousValue = consecutiveSessionFailures.getAndSet(0);
+    if (previousValue > 0) {
+      LOG.info(
+          String.format(
+              "Consecutive session failure counter reset from %d to 0. Node availability restored.",
+              previousValue));
+    }
+  }
+
   @ManagedAttribute(name = "RemoteNodeUri")
   public URI getExternalUri() {
     return this.getUri();
@@ -451,6 +485,21 @@ public class LocalNode extends Node implements Closeable {
       CreateSessionRequest sessionRequest) {
     Require.nonNull("Session request", sessionRequest);
 
+    // Early check before acquiring lock (fast path for draining nodes)
+    if (isDraining()) {
+      return Either.left(
+          new RetrySessionRequestException("The node is draining. Cannot accept new sessions."));
+    }
+
+    // Early check for failure threshold (fast path for unhealthy nodes)
+    if (nodeDownFailureThreshold > 0
+        && consecutiveSessionFailures.get() >= nodeDownFailureThreshold) {
+      return Either.left(
+          new RetrySessionRequestException(
+              "The node is marked as DOWN due to exceeding the failure threshold. Cannot accept new"
+                  + " sessions."));
+    }
+
     Lock lock = drainLock.readLock();
     lock.lock();
 
@@ -462,18 +511,7 @@ public class LocalNode extends Node implements Closeable {
       attributeMap.put(
           "session.request.downstreamdialect", sessionRequest.getDownstreamDialects().toString());
 
-      int currentSessionCount = getCurrentSessionCount();
-      span.setAttribute("current.session.count", currentSessionCount);
-      attributeMap.put("current.session.count", currentSessionCount);
-
-      if (currentSessionCount >= maxSessionCount) {
-        span.setAttribute(AttributeKey.ERROR.getKey(), true);
-        span.setStatus(Status.RESOURCE_EXHAUSTED);
-        attributeMap.put("max.session.count", maxSessionCount);
-        span.addEvent("Max session count reached", attributeMap);
-        return Either.left(new RetrySessionRequestException("Max session count reached."));
-      }
-
+      // Re-check after acquiring lock (double-checked locking pattern)
       if (isDraining()) {
         span.setStatus(
             Status.UNAVAILABLE.withDescription(
@@ -482,21 +520,46 @@ public class LocalNode extends Node implements Closeable {
             new RetrySessionRequestException("The node is draining. Cannot accept new sessions."));
       }
 
-      // Identify possible slots to use as quickly as possible to enable concurrent session starting
-      SessionSlot slotToUse = null;
-      synchronized (factories) {
-        for (SessionSlot factory : factories) {
-          if (!factory.isAvailable() || !factory.test(sessionRequest.getDesiredCapabilities())) {
-            continue;
-          }
+      // Re-check failure threshold after acquiring lock
+      if (nodeDownFailureThreshold > 0
+          && consecutiveSessionFailures.get() >= nodeDownFailureThreshold) {
+        span.setStatus(
+            Status.UNAVAILABLE.withDescription(
+                "The node is marked as DOWN due to exceeding the failure threshold."));
+        return Either.left(
+            new RetrySessionRequestException(
+                "The node is marked as DOWN due to exceeding the failure threshold. "
+                    + "Cannot accept new sessions."));
+      }
 
-          factory.reserve();
+      // Atomically check and reserve a session slot to prevent exceeding maxSessionCount
+      // This fixes the race condition where multiple threads could pass the count check
+      int currentCount = reservedOrActiveSessionCount.incrementAndGet();
+      span.setAttribute("current.session.count", currentCount);
+      attributeMap.put("current.session.count", currentCount);
+
+      if (currentCount > maxSessionCount) {
+        reservedOrActiveSessionCount.decrementAndGet();
+        span.setAttribute(AttributeKey.ERROR.getKey(), true);
+        span.setStatus(Status.RESOURCE_EXHAUSTED);
+        attributeMap.put("max.session.count", maxSessionCount);
+        span.addEvent("Max session count reached", attributeMap);
+        return Either.left(new RetrySessionRequestException("Max session count reached."));
+      }
+
+      // Identify possible slots to use as quickly as possible to enable concurrent session starting
+      // Uses lock-free tryReserve() for better concurrency - no global lock needed
+      SessionSlot slotToUse = null;
+      Capabilities desiredCaps = sessionRequest.getDesiredCapabilities();
+      for (SessionSlot factory : factories) {
+        if (factory.tryReserve(desiredCaps)) {
           slotToUse = factory;
           break;
         }
       }
 
       if (slotToUse == null) {
+        reservedOrActiveSessionCount.decrementAndGet();
         span.setAttribute(AttributeKey.ERROR.getKey(), true);
         span.setStatus(Status.NOT_FOUND);
         span.addEvent("No slot matched the requested capabilities. ", attributeMap);
@@ -506,6 +569,7 @@ public class LocalNode extends Node implements Closeable {
 
       if (!decrementSessionCount()) {
         slotToUse.release();
+        reservedOrActiveSessionCount.decrementAndGet();
         span.setAttribute(AttributeKey.ERROR.getKey(), true);
         span.setStatus(Status.RESOURCE_EXHAUSTED);
         attributeMap.put("drain.after.session.count", configuredSessionCount);
@@ -541,6 +605,9 @@ public class LocalNode extends Node implements Closeable {
         }
         currentSessions.put(session.getId(), slotToUse);
 
+        // Reset consecutive failure counter on successful session creation
+        consecutiveSessionFailures.set(0);
+
         SessionId sessionId = session.getId();
         Capabilities caps = session.getCapabilities();
         SESSION_ID.accept(span, sessionId);
@@ -574,6 +641,20 @@ public class LocalNode extends Node implements Closeable {
                 getEncoder(session.getDownstreamDialect()).apply(externalSession)));
       } else {
         slotToUse.release();
+        reservedOrActiveSessionCount.decrementAndGet();
+        // Restore session count that was decremented earlier, so node doesn't drain prematurely
+        restoreSessionCount();
+
+        // Track consecutive session creation failures
+        int failures = consecutiveSessionFailures.incrementAndGet();
+        if (nodeDownFailureThreshold > 0 && failures >= nodeDownFailureThreshold) {
+          LOG.warning(
+              String.format(
+                  "Node has reached the failure threshold (%d consecutive failures). "
+                      + "Node will be marked as DOWN.",
+                  nodeDownFailureThreshold));
+        }
+
         if (downloadsTfs != null) {
           downloadsTfs.deleteTemporaryFiles();
           downloadsTfs.deleteBaseDir();
@@ -709,7 +790,7 @@ public class LocalNode extends Node implements Closeable {
   }
 
   @Override
-  public TemporaryFilesystem getDownloadsFilesystem(SessionId sessionId) throws IOException {
+  public TemporaryFilesystem getDownloadsFilesystem(SessionId sessionId) {
     return downloadsTempFileSystem.getIfPresent(sessionId);
   }
 
@@ -763,6 +844,8 @@ public class LocalNode extends Node implements Closeable {
         return listDownloadedFiles(downloadsDirectory);
       }
       if (req.getMethod().equals(HttpMethod.GET)) {
+        // Left here for backward compatibility.
+        // Remove this IF in Selenium 4.41, 4.42 or 4.43
         return getDownloadedFile(downloadsDirectory, extractFileName(req));
       }
       if (req.getMethod().equals(HttpMethod.DELETE)) {
@@ -792,7 +875,10 @@ public class LocalNode extends Node implements Closeable {
     File[] files = Optional.ofNullable(downloadsDirectory.listFiles()).orElse(new File[] {});
     List<String> fileNames = Arrays.stream(files).map(File::getName).collect(Collectors.toList());
     List<DownloadedFile> fileInfos =
-        Arrays.stream(files).map(this::getFileInfo).collect(Collectors.toList());
+        Arrays.stream(files)
+            .map(this::getFileInfo)
+            .filter(file -> file.getLastModifiedTime() > 0)
+            .collect(Collectors.toList());
 
     Map<String, Object> data =
         Map.of(
@@ -810,6 +896,8 @@ public class LocalNode extends Node implements Closeable {
           attributes.creationTime().toMillis(),
           attributes.lastModifiedTime().toMillis(),
           attributes.size());
+    } catch (NoSuchFileException e) {
+      return new DownloadedFile(file.getName(), -1, -1, -1);
     } catch (IOException e) {
       throw new UncheckedIOException("Failed to get file attributes: " + file.getAbsolutePath(), e);
     }
@@ -832,6 +920,14 @@ public class LocalNode extends Node implements Closeable {
                         "Please specify file to download in payload as {\"name\":"
                             + " \"fileToDownload\"}"));
     File file = findDownloadedFile(downloadsDirectory, filename);
+    String contentType =
+        requireNonNullElseGet(
+            (String) incoming.get("format"), () -> MediaType.JSON_UTF_8.toString());
+
+    if (MediaType.OCTET_STREAM.toString().equalsIgnoreCase(contentType)) {
+      return fileAsBinaryResponse(file);
+    }
+
     String content = Zip.zip(file);
     Map<String, Object> data =
         Map.of(
@@ -842,12 +938,18 @@ public class LocalNode extends Node implements Closeable {
     return new HttpResponse().setContent(asJson(result));
   }
 
+  /** Left here for backward compatibility. Remove this method in Selenium 4.41, 4.42 or 4.43 */
+  @Deprecated
   private HttpResponse getDownloadedFile(File downloadsDirectory, String fileName)
       throws IOException {
     if (fileName.isEmpty()) {
       throw new WebDriverException("Please specify file to download in URL");
     }
     File file = findDownloadedFile(downloadsDirectory, fileName);
+    return fileAsBinaryResponse(file);
+  }
+
+  private HttpResponse fileAsBinaryResponse(File file) throws IOException {
     BasicFileAttributes attributes = readAttributes(file.toPath(), BasicFileAttributes.class);
     return new HttpResponse()
         .setHeader("Content-Type", MediaType.OCTET_STREAM.toString())
@@ -863,7 +965,7 @@ public class LocalNode extends Node implements Closeable {
   private File findDownloadedFile(File downloadsDirectory, String filename)
       throws WebDriverException {
     List<File> matchingFiles =
-        asList(
+        List.of(
             requireNonNullElseGet(
                 downloadsDirectory.listFiles((dir, name) -> name.equals(filename)),
                 () -> new File[0]));
@@ -885,7 +987,7 @@ public class LocalNode extends Node implements Closeable {
 
   private static List<File> downloadedFiles(File downloadsDirectory) {
     File[] files = requireNonNullElseGet(downloadsDirectory.listFiles(), () -> new File[0]);
-    return asList(files);
+    return List.of(files);
   }
 
   private HttpResponse deleteDownloadedFile(File downloadsDirectory) {
@@ -1072,10 +1174,16 @@ public class LocalNode extends Node implements Closeable {
                       lastStarted,
                       session);
                 })
-            .collect(toImmutableSet());
+            .collect(toUnmodifiableSet());
 
     Availability availability = isDraining() ? DRAINING : UP;
 
+    // Check if consecutive session creation failures have exceeded the threshold
+    if (nodeDownFailureThreshold > 0
+        && consecutiveSessionFailures.get() >= nodeDownFailureThreshold) {
+      availability = DOWN;
+    }
+
     // Check status in case this Node is a RelayNode
     Optional<SessionSlot> relaySlot =
         factories.stream().filter(SessionSlot::hasRelayFactory).findFirst();
@@ -1163,6 +1271,20 @@ public class LocalNode extends Node implements Closeable {
     return true;
   }
 
+  /**
+   * Restores the session count when session creation fails after decrementSessionCount() was
+   * called. This prevents the node from draining prematurely due to failed session attempts.
+   */
+  private void restoreSessionCount() {
+    if (this.drainAfterSessions) {
+      int remainingSessions = this.sessionCount.incrementAndGet();
+      LOG.log(
+          Debug.getDebugLogLevel(),
+          "Session creation failed, restored count. {0} remaining sessions before draining Node",
+          remainingSessions);
+    }
+  }
+
   private Map<String, Object> toJson() {
     return Map.of(
         "id",
@@ -1184,7 +1306,7 @@ public class LocalNode extends Node implements Closeable {
     private final URI uri;
     private final URI gridUri;
     private final Secret registrationSecret;
-    private final ImmutableList.Builder<SessionSlot> factories;
+    private final List<SessionSlot> factories;
     private int maxSessions = NodeOptions.DEFAULT_MAX_SESSIONS;
     private int drainAfterSessionCount = NodeOptions.DEFAULT_DRAIN_AFTER_SESSION_COUNT;
     private boolean cdpEnabled = NodeOptions.DEFAULT_ENABLE_CDP;
@@ -1195,6 +1317,8 @@ public class LocalNode extends Node implements Closeable {
     private Duration heartbeatPeriod = Duration.ofSeconds(NodeOptions.DEFAULT_HEARTBEAT_PERIOD);
     private boolean managedDownloadsEnabled = false;
     private int connectionLimitPerSession = -1;
+    // Default 0 means disabled (unlimited retries allowed)
+    private int nodeDownFailureThreshold = 0;
 
     private Builder(Tracer tracer, EventBus bus, URI uri, URI gridUri, Secret registrationSecret) {
       this.tracer = Require.nonNull("Tracer", tracer);
@@ -1202,7 +1326,7 @@ public class LocalNode extends Node implements Closeable {
       this.uri = Require.nonNull("Remote node URI", uri);
       this.gridUri = Require.nonNull("Grid URI", gridUri);
       this.registrationSecret = Require.nonNull("Registration secret", registrationSecret);
-      this.factories = ImmutableList.builder();
+      this.factories = new ArrayList<>();
     }
 
     public Builder add(Capabilities stereotype, SessionFactory factory) {
@@ -1254,6 +1378,20 @@ public class LocalNode extends Node implements Closeable {
       return this;
     }
 
+    /**
+     * Sets the maximum number of consecutive session creation failures allowed before the node is
+     * marked as DOWN. This helps detect and isolate unhealthy nodes that consistently fail to
+     * create sessions.
+     *
+     * @param threshold the maximum number of consecutive failures allowed (0 to disable, which is
+     *     the default)
+     * @return this builder
+     */
+    public Builder nodeDownFailureThreshold(int threshold) {
+      this.nodeDownFailureThreshold = threshold;
+      return this;
+    }
+
     public LocalNode build() {
       return new LocalNode(
           tracer,
@@ -1268,10 +1406,11 @@ public class LocalNode extends Node implements Closeable {
           ticker,
           sessionTimeout,
           heartbeatPeriod,
-          factories.build(),
+          List.copyOf(factories),
           registrationSecret,
           managedDownloadsEnabled,
-          connectionLimitPerSession);
+          connectionLimitPerSession,
+          nodeDownFailureThreshold);
     }
 
     public Advanced advanced() {
@@ -1281,13 +1420,7 @@ public class LocalNode extends Node implements Closeable {
     public class Advanced {
 
       public Advanced clock(Clock clock) {
-        ticker =
-            new Ticker() {
-              @Override
-              public long read() {
-                return clock.instant().toEpochMilli() * Duration.ofMillis(1).toNanos();
-              }
-            };
+        ticker = () -> clock.instant().toEpochMilli() * Duration.ofMillis(1).toNanos();
         return this;
       }
 
