@@ -17,12 +17,12 @@
 
 package org.openqa.selenium.grid.sessionqueue.httpd;
 
-import com.google.common.collect.ImmutableMap;
+import java.util.Map;
 import org.openqa.selenium.grid.config.MapConfig;
 
 class DefaultNewSessionQueueConfig extends MapConfig {
 
   DefaultNewSessionQueueConfig() {
-    super(ImmutableMap.of("server", ImmutableMap.of("port", 5559)));
+    super(Map.of("server", Map.of("port", 5559)));
   }
 }
