@@ -20,9 +20,9 @@ package org.openqa.selenium.remote;
 import static java.util.Collections.singleton;
 import static java.util.concurrent.TimeUnit.SECONDS;
 import static java.util.logging.Level.SEVERE;
-import static org.openqa.selenium.HasDownloads.DownloadedFile;
 import static org.openqa.selenium.remote.CapabilityType.PLATFORM_NAME;
 
+import com.google.common.net.MediaType;
 import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -83,6 +83,7 @@ import org.openqa.selenium.interactions.Interactive;
 import org.openqa.selenium.interactions.Sequence;
 import org.openqa.selenium.internal.Debug;
 import org.openqa.selenium.internal.Require;
+import org.openqa.selenium.io.Zip;
 import org.openqa.selenium.logging.LocalLogs;
 import org.openqa.selenium.logging.LoggingHandler;
 import org.openqa.selenium.logging.Logs;
@@ -113,6 +114,10 @@ public class RemoteWebDriver
         PrintsPage,
         TakesScreenshot {
 
+  static {
+    org.openqa.selenium.internal.Debug.configureLogger();
+  }
+
   private static final Logger LOG = Logger.getLogger(RemoteWebDriver.class.getName());
 
   /** Boolean system property that defines whether the tracing is enabled or not. */
@@ -121,15 +126,18 @@ public class RemoteWebDriver
   private final ElementLocation elementLocation = new ElementLocation();
   private Level level = Level.FINE;
   private ErrorHandler errorHandler = new ErrorHandler();
+  private final ClientConfig clientConfig;
   private CommandExecutor executor;
   protected Capabilities capabilities;
   private SessionId sessionId;
   private FileDetector fileDetector = new UselessFileDetector();
-  private ExecuteMethod executeMethod;
+  private final ExecuteMethod executeMethod = new RemoteExecuteMethod(this);
 
   private JsonToWebElementConverter converter;
 
   private Logs remoteLogs;
+
+  @SuppressWarnings("deprecation")
   private LocalLogs localLogs;
 
   private Script remoteScript;
@@ -139,6 +147,7 @@ public class RemoteWebDriver
   // For cglib
   protected RemoteWebDriver() {
     this.capabilities = init(new ImmutableCapabilities());
+    this.clientConfig = ClientConfig.defaultConfig();
   }
 
   public RemoteWebDriver(Capabilities capabilities) {
@@ -153,20 +162,42 @@ public class RemoteWebDriver
   }
 
   public RemoteWebDriver(URL remoteAddress, Capabilities capabilities) {
+    this(remoteAddress, capabilities, ClientConfig.defaultConfig());
+  }
+
+  public RemoteWebDriver(URL remoteAddress, Capabilities capabilities, ClientConfig clientConfig) {
     this(
         createExecutor(
             Require.nonNull("Server URL", remoteAddress),
-            Boolean.parseBoolean(System.getProperty(WEBDRIVER_REMOTE_ENABLE_TRACING, "true"))),
-        Require.nonNull("Capabilities", capabilities));
+            Boolean.parseBoolean(System.getProperty(WEBDRIVER_REMOTE_ENABLE_TRACING, "true")),
+            clientConfig),
+        Require.nonNull("Capabilities", capabilities),
+        clientConfig);
   }
 
   public RemoteWebDriver(URL remoteAddress, Capabilities capabilities, boolean enableTracing) {
-    this(
-        createExecutor(Require.nonNull("Server URL", remoteAddress), enableTracing),
-        Require.nonNull("Capabilities", capabilities));
+    this(remoteAddress, capabilities, ClientConfig.defaultConfig(), enableTracing);
   }
 
+  public RemoteWebDriver(
+      URL remoteAddress,
+      Capabilities capabilities,
+      ClientConfig clientConfig,
+      boolean enableTracing) {
+    this(
+        createExecutor(Require.nonNull("Server URL", remoteAddress), enableTracing, clientConfig),
+        Require.nonNull("Capabilities", capabilities),
+        clientConfig);
+  }
+
+  @SuppressWarnings("deprecation")
   public RemoteWebDriver(CommandExecutor executor, Capabilities capabilities) {
+    this(executor, capabilities, ClientConfig.defaultConfig());
+  }
+
+  public RemoteWebDriver(
+      CommandExecutor executor, Capabilities capabilities, ClientConfig clientConfig) {
+    this.clientConfig = Require.nonNull("Client config", clientConfig);
     this.executor = Require.nonNull("Command executor", executor);
     this.capabilities = init(capabilities);
 
@@ -195,8 +226,9 @@ public class RemoteWebDriver
     }
   }
 
-  private static CommandExecutor createExecutor(URL remoteAddress, boolean enableTracing) {
-    ClientConfig config = ClientConfig.defaultConfig().baseUrl(remoteAddress);
+  private static CommandExecutor createExecutor(
+      URL remoteAddress, boolean enableTracing, ClientConfig clientConfig) {
+    ClientConfig config = clientConfig.baseUrl(remoteAddress);
     if (enableTracing) {
       Tracer tracer = OpenTelemetryTracer.getInstance();
       CommandExecutor executor =
@@ -218,10 +250,17 @@ public class RemoteWebDriver
   private Capabilities init(Capabilities capabilities) {
     capabilities = capabilities == null ? new ImmutableCapabilities() : capabilities;
 
-    LOG.addHandler(LoggingHandler.getInstance());
-
     converter = new JsonToWebElementConverter(this);
-    executeMethod = new RemoteExecuteMethod(this);
+
+    initLocalLogs();
+    remoteLogs = new RemoteLogs(executeMethod);
+
+    return capabilities;
+  }
+
+  @SuppressWarnings("deprecation")
+  private void initLocalLogs() {
+    LOG.addHandler(LoggingHandler.getInstance());
 
     Set<String> logTypesToIgnore = Set.of();
 
@@ -229,9 +268,6 @@ public class RemoteWebDriver
     LocalLogs clientLogs =
         LocalLogs.getHandlerBasedLoggerInstance(LoggingHandler.getInstance(), logTypesToIgnore);
     localLogs = LocalLogs.getCombinedLogsHolder(clientLogs, performanceLogger);
-    remoteLogs = new RemoteLogs(executeMethod, localLogs);
-
-    return capabilities;
   }
 
   public SessionId getSessionId() {
@@ -308,6 +344,10 @@ public class RemoteWebDriver
     this.errorHandler = handler;
   }
 
+  public ClientConfig getClientConfig() {
+    return clientConfig;
+  }
+
   public CommandExecutor getCommandExecutor() {
     return executor;
   }
@@ -730,11 +770,23 @@ public class RemoteWebDriver
   public void downloadFile(String fileName, Path targetLocation) throws IOException {
     requireDownloadsEnabled(capabilities);
 
-    Response response = execute(DriverCommand.GET_DOWNLOADED_FILE, Map.of("name", fileName));
-
-    Contents.Supplier content = (Contents.Supplier) response.getValue();
-    try (InputStream fileContent = content.get()) {
-      Files.copy(new BufferedInputStream(fileContent), targetLocation.resolve(fileName));
+    Response response =
+        execute(
+            DriverCommand.DOWNLOAD_FILE,
+            Map.of("name", fileName, "format", MediaType.OCTET_STREAM.toString()));
+    if (response.getValue() instanceof Contents.Supplier) {
+      // Selenium Grid 4.40.0 or newer
+      Contents.Supplier content = (Contents.Supplier) response.getValue();
+      try (InputStream fileContent = content.get()) {
+        Files.createDirectories(targetLocation);
+        Files.copy(new BufferedInputStream(fileContent), targetLocation.resolve(fileName));
+      }
+    } else if (response.getValue() instanceof Map) {
+      // Selenium Grid 4.39.0 or older
+      String contents = ((Map<String, String>) response.getValue()).get("contents");
+      Zip.unzip(contents, targetLocation.toFile());
+    } else {
+      throw new UnsupportedOperationException("Unexpected grid response: " + response);
     }
   }
 
