@@ -18,7 +18,6 @@
 package org.openqa.selenium.safari;
 
 import static java.util.Collections.unmodifiableList;
-import static java.util.Collections.unmodifiableMap;
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static org.openqa.selenium.remote.Browser.SAFARI;
 
@@ -28,10 +27,9 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.time.Duration;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import org.jspecify.annotations.Nullable;
 import org.openqa.selenium.Capabilities;
 import org.openqa.selenium.WebDriverException;
 import org.openqa.selenium.net.PortProber;
@@ -64,18 +62,13 @@ public class SafariDriverService extends DriverService {
    * @throws IOException If an I/O error occurs.
    */
   public SafariDriverService(
-      File executable,
+      @Nullable File executable,
       int port,
-      Duration timeout,
-      List<String> args,
-      Map<String, String> environment)
+      @Nullable Duration timeout,
+      @Nullable List<String> args,
+      @Nullable Map<String, String> environment)
       throws IOException {
-    super(
-        executable,
-        port,
-        timeout,
-        unmodifiableList(new ArrayList<>(args)),
-        unmodifiableMap(new HashMap<>(environment)));
+    super(executable, port, timeout, List.copyOf(args), Map.copyOf(environment));
   }
 
   public String getDriverName() {
@@ -126,7 +119,7 @@ public class SafariDriverService extends DriverService {
   public static class Builder
       extends DriverService.Builder<SafariDriverService, SafariDriverService.Builder> {
 
-    private Boolean diagnose;
+    private @Nullable Boolean diagnose;
 
     @Override
     public int score(Capabilities capabilities) {
@@ -139,13 +132,13 @@ public class SafariDriverService extends DriverService {
       return score;
     }
 
-    public Builder withLogging(Boolean logging) {
+    public Builder withLogging(@Nullable Boolean logging) {
       this.diagnose = logging;
       return this;
     }
 
     @Override
-    public Builder withLogFile(File logFile) {
+    public Builder withLogFile(@Nullable File logFile) {
       throw new WebDriverException(
           "Can not set log location for Safari; use withLogging(true) and locate log in"
               + " ~/Library/Logs/com.apple.WebDriver/");
@@ -160,16 +153,22 @@ public class SafariDriverService extends DriverService {
 
     @Override
     protected List<String> createArgs() {
-      List<String> args = new ArrayList<>(Arrays.asList("--port", String.valueOf(getPort())));
+      List<String> args = new ArrayList<>(3);
+      args.add("--port");
+      args.add(String.valueOf(getPort()));
       if (Boolean.TRUE.equals(diagnose)) {
         args.add("--diagnose");
       }
-      return args;
+      return unmodifiableList(args);
     }
 
     @Override
     protected SafariDriverService createDriverService(
-        File exe, int port, Duration timeout, List<String> args, Map<String, String> environment) {
+        @Nullable File exe,
+        int port,
+        @Nullable Duration timeout,
+        @Nullable List<String> args,
+        @Nullable Map<String, String> environment) {
       try {
         withLogOutput(OutputStream.nullOutputStream());
         return new SafariDriverService(exe, port, timeout, args, environment);
