@@ -26,8 +26,6 @@ import static org.openqa.selenium.testing.drivers.Browser.EDGE;
 import static org.openqa.selenium.testing.drivers.Browser.FIREFOX;
 import static org.openqa.selenium.testing.drivers.Browser.SAFARI;
 
-import com.google.common.base.Joiner;
-import com.google.common.net.HostAndPort;
 import io.netty.handler.codec.http.FullHttpResponse;
 import io.netty.handler.codec.http.HttpRequest;
 import java.net.URI;
@@ -90,11 +88,11 @@ class ProxySettingTest extends JupiterTestBase {
         SimpleHttpServer pacFileServer =
             createPacfileServer(
                 "/proxy.pac",
-                Joiner.on('\n')
-                    .join(
-                        "function FindProxyForURL(url, host) {",
-                        "  return 'PROXY " + getHostAndPort(helloServer) + "';",
-                        "}"))) {
+                String.join(
+                    "\n",
+                    "function FindProxyForURL(url, host) {",
+                    "  return 'PROXY " + getHostAndPort(helloServer) + "';",
+                    "}"))) {
 
       Proxy proxy = new Proxy();
       proxy.setProxyAutoconfigUrl("http://" + getHostAndPort(pacFileServer) + "/proxy.pac");
@@ -125,14 +123,14 @@ class ProxySettingTest extends JupiterTestBase {
         SimpleHttpServer pacFileServer =
             createPacfileServer(
                 "/proxy.pac",
-                Joiner.on('\n')
-                    .join(
-                        "function FindProxyForURL(url, host) {",
-                        "  if (url.indexOf('" + getHostAndPort(helloServer) + "') != -1) {",
-                        "    return 'PROXY " + getHostAndPort(goodbyeServer) + "';",
-                        "  }",
-                        "  return 'DIRECT';",
-                        "}"))) {
+                String.join(
+                    "\n",
+                    "function FindProxyForURL(url, host) {",
+                    "  if (url.indexOf('" + getHostAndPort(helloServer) + "') != -1) {",
+                    "    return 'PROXY " + getHostAndPort(goodbyeServer) + "';",
+                    "  }",
+                    "  return 'DIRECT';",
+                    "}"))) {
 
       Proxy proxy = new Proxy();
       proxy.setProxyAutoconfigUrl("http://" + getHostAndPort(pacFileServer) + "/proxy.pac");
@@ -168,9 +166,9 @@ class ProxySettingTest extends JupiterTestBase {
     return server;
   }
 
-  private static HostAndPort getHostAndPort(SimpleHttpServer server) {
+  private static String getHostAndPort(SimpleHttpServer server) {
     URI baseUri = server.baseUri();
-    return HostAndPort.fromParts(baseUri.getHost(), baseUri.getPort());
+    return String.format("%s:%s", baseUri.getHost(), baseUri.getPort());
   }
 
   public static class FakeProxyServer extends SimpleHttpServer {
