@@ -17,9 +17,8 @@
 
 package org.openqa.selenium.bidi;
 
-import static org.assertj.core.api.AssertionsForClassTypes.assertThat;
+import static org.assertj.core.api.Assertions.assertThat;
 
-import java.util.Collections;
 import org.junit.jupiter.api.Test;
 import org.openqa.selenium.testing.JupiterTestBase;
 
@@ -29,8 +28,7 @@ class BiDiSessionTest extends JupiterTestBase {
   void shouldBeAbleToCreateABiDiSession() {
     BiDi biDi = ((HasBiDi) driver).getBiDi();
 
-    BiDiSessionStatus status =
-        biDi.send(new Command<>("session.status", Collections.emptyMap(), BiDiSessionStatus.class));
+    BiDiSessionStatus status = biDi.getBidiSessionStatus();
     assertThat(status).isNotNull();
     assertThat(status.getMessage()).isNotEmpty();
   }
