@@ -34,13 +34,9 @@ import static org.openqa.selenium.firefox.FirefoxOptions.FIREFOX_OPTIONS;
 import static org.openqa.selenium.remote.CapabilityType.ACCEPT_INSECURE_CERTS;
 import static org.openqa.selenium.remote.CapabilityType.PAGE_LOAD_STRATEGY;
 
-import com.google.common.collect.ImmutableMap;
 import java.io.File;
 import java.io.IOException;
-import java.nio.file.Files;
-import java.nio.file.Path;
 import java.nio.file.Paths;
-import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -53,6 +49,7 @@ import org.openqa.selenium.MutableCapabilities;
 import org.openqa.selenium.PageLoadStrategy;
 import org.openqa.selenium.WebDriverException;
 import org.openqa.selenium.internal.Require;
+import org.openqa.selenium.remote.DesiredCapabilities;
 import org.openqa.selenium.testing.TestUtilities;
 
 @Tag("UnitTests")
@@ -72,8 +69,7 @@ class FirefoxOptionsTest {
   @Test
   void canInitFirefoxOptionsWithCapabilitiesThatContainFirefoxOptionsAsMap() {
     FirefoxProfile profile = new FirefoxProfile();
-    Capabilities caps =
-        new ImmutableCapabilities(FIREFOX_OPTIONS, ImmutableMap.of("profile", profile));
+    Capabilities caps = new ImmutableCapabilities(FIREFOX_OPTIONS, Map.of("profile", profile));
 
     FirefoxOptions options = new FirefoxOptions(caps);
 
@@ -214,7 +210,7 @@ class FirefoxOptionsTest {
     Object options2 = options.asMap().get(FirefoxOptions.FIREFOX_OPTIONS);
     assertThat(options2)
         .asInstanceOf(InstanceOfAssertFactories.MAP)
-        .containsEntry("args", Arrays.asList("-a", "-b"));
+        .containsEntry("args", List.of("-a", "-b"));
   }
 
   @Test
@@ -236,21 +232,6 @@ class FirefoxOptionsTest {
         .containsEntry("boolean.pref", true);
   }
 
-  @Test
-  void canConvertOptionsWithBinaryToCapabilitiesAndRestoreBack() throws IOException {
-    // Don't assume Firefox is actually installed and available
-    Path tempFile = Files.createTempFile("firefoxoptions", "test");
-
-    FirefoxOptions options =
-        new FirefoxOptions(
-            new MutableCapabilities(
-                new FirefoxOptions().setBinary(new FirefoxBinary(tempFile.toFile()))));
-    Object options2 = options.asMap().get(FirefoxOptions.FIREFOX_OPTIONS);
-    assertThat(options2)
-        .asInstanceOf(InstanceOfAssertFactories.MAP)
-        .containsEntry("binary", tempFile.toFile().getPath());
-  }
-
   @Test
   void roundTrippingToCapabilitiesAndBackWorks() {
     FirefoxOptions expected = new FirefoxOptions().addPreference("cake", "walk");
@@ -409,7 +390,7 @@ class FirefoxOptionsTest {
 
     MutableCapabilities browserCaps = new MutableCapabilities();
 
-    browserCaps.setCapability("args", Arrays.asList("verbose", "silent"));
+    browserCaps.setCapability("args", List.of("verbose", "silent"));
     browserCaps.setCapability("prefs", prefs);
     browserCaps.setCapability("profile", profile.toJson());
     browserCaps.setCapability("binary", binary.getPath());
@@ -479,6 +460,26 @@ class FirefoxOptionsTest {
     assertThat(caps.getCapabilityNames()).contains(FIREFOX_OPTIONS);
   }
 
+  @Test
+  void issue15991() {
+    DesiredCapabilities options =
+        new DesiredCapabilities(Map.of("moz:firefoxOptions", Map.of("args", List.of("1", "2"))));
+
+    FirefoxOptions result = new FirefoxOptions().merge(options);
+
+    assertThat(result.asMap())
+        .containsExactlyInAnyOrderEntriesOf(
+            Map.of(
+                "acceptInsecureCerts",
+                true,
+                "browserName",
+                "firefox",
+                "moz:firefoxOptions",
+                Map.of(
+                    "args", List.of("1", "2"),
+                    "prefs", Map.of("remote.active-protocols", 1))));
+  }
+
   private static class JreSystemProperty {
 
     private final String name;
