@@ -20,12 +20,12 @@ package org.openqa.selenium.grid.data;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.openqa.selenium.grid.data.Availability.UP;
 
-import com.google.common.collect.ImmutableMap;
-import com.google.common.collect.ImmutableSet;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.time.Duration;
 import java.time.Instant;
+import java.util.Map;
+import java.util.Set;
 import java.util.UUID;
 import org.junit.jupiter.api.Test;
 import org.openqa.selenium.ImmutableCapabilities;
@@ -43,7 +43,7 @@ class NodeStatusTest {
             nodeId,
             new URI("http://localhost:23456"),
             100,
-            ImmutableSet.of(
+            Set.of(
                 new Slot(
                     new SlotId(nodeId, UUID.randomUUID()),
                     stereotype,
@@ -58,7 +58,7 @@ class NodeStatusTest {
             Duration.ofSeconds(10),
             Duration.ofSeconds(300),
             "4.0.0",
-            ImmutableMap.of(
+            Map.of(
                 "name", "Max OS X",
                 "arch", "x86_64",
                 "version", "10.15.7"));
@@ -74,7 +74,7 @@ class NodeStatusTest {
   }
 
   @Test
-  void withoutSessionTimeoutInJsonStatus() throws URISyntaxException {
+  void withoutSessionTimeoutInJsonStatus() {
     String source =
         "{\n"
             + "      \"availability\": \"UP\",\n"
@@ -111,7 +111,7 @@ class NodeStatusTest {
   }
 
   @Test
-  void withSessionTimeoutInJsonStatus() throws URISyntaxException {
+  void withSessionTimeoutInJsonStatus() {
     String source =
         "{\n"
             + "      \"availability\": \"UP\",\n"
