@@ -18,7 +18,6 @@
 package org.openqa.selenium.grid.distributor;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.time.Duration;
 import java.time.Instant;
@@ -96,7 +95,7 @@ public class DistributorDrainingTest extends DistributorTestBase {
 
     assertThat(latch.getCount()).isEqualTo(1);
 
-    assertThat(local.getStatus().getNodes().size()).isEqualTo(1);
+    assertThat(local.getStatus().getNodes()).hasSize(1);
   }
 
   @Test
@@ -153,7 +152,7 @@ public class DistributorDrainingTest extends DistributorTestBase {
 
     local.drain(node.getId());
 
-    assertThat(local.getStatus().getNodes().size()).isEqualTo(1);
+    assertThat(local.getStatus().getNodes()).hasSize(1);
 
     node.stop(firstResponse.right().getSession().getId());
     node.stop(secondResponse.right().getSession().getId());
@@ -269,7 +268,7 @@ public class DistributorDrainingTest extends DistributorTestBase {
     local.add(node);
     local.drain(node.getId());
 
-    assertTrue(node.isDraining());
+    assertThat(node.isDraining()).isTrue();
 
     Either<SessionNotCreatedException, CreateSessionResponse> result =
         local.newSession(createRequest(caps));
