@@ -20,7 +20,6 @@ import pytest
 from selenium.common.exceptions import InvalidArgumentException
 from selenium.webdriver.common.options import PageLoadStrategy
 from selenium.webdriver.common.proxy import Proxy, ProxyType
-from selenium.webdriver.firefox.firefox_binary import FirefoxBinary
 from selenium.webdriver.firefox.firefox_profile import FirefoxProfile
 from selenium.webdriver.firefox.options import Options
 
@@ -30,22 +29,6 @@ def options():
     return Options()
 
 
-def test_set_binary_with_firefox_binary(options):
-    binary = FirefoxBinary("foo")
-    options.binary = binary
-    assert options.binary_location == "foo"
-
-
-def test_set_binary_with_path(options):
-    options.binary = "/foo"
-    assert options.binary_location == "/foo"
-
-
-def test_get_binary(options):
-    options.binary = "/foo"
-    assert options.binary._start_cmd == "/foo"
-
-
 def test_set_binary_location(options):
     options.binary_location = "/foo"
     assert options.binary_location == "/foo"
@@ -141,7 +124,7 @@ def test_creates_capabilities(options):
     assert "foo" in opts["args"]
     assert opts["binary"] == "/bar"
     assert opts["prefs"]["foo"] == "bar"
-    assert isinstance(opts["profile"], str) and opts["profile"]
+    assert isinstance(opts["profile"], str)
     assert caps["proxy"]["proxyType"] == "manual"
     assert opts["log"]["level"] == "debug"
 
