@@ -31,9 +31,10 @@ module Selenium
 
         include LocalDriver
 
-        def initialize(options: nil, service: nil, url: nil, **opts)
-          caps, url = initialize_local_driver(options, service, url)
-          super(caps: caps, url: url, **opts)
+        def initialize(options: nil, service: nil, url: nil, **)
+          initialize_local_driver(options, service, url) do |caps, driver_url|
+            super(caps: caps, url: driver_url, **)
+          end
         end
 
         def browser
