@@ -45,13 +45,12 @@ module Selenium
         }.to yield_control
       end
 
-      it 'propagates errors in events' do
+      it 'logs errors in events' do
+        driver.devtools.page.enable
+        driver.devtools.page.on(:load_event_fired) { raise 'This is fine!' }
         expect {
-          driver.devtools.page.enable
-          driver.devtools.page.on(:load_event_fired) { raise 'This is fine!' }
           driver.navigate.to url_for('xhtmlTest.html')
-          sleep 0.5
-        }.to raise_error(RuntimeError, 'This is fine!')
+        }.to have_error(:ws, /This is fine!/)
       end
 
       describe '#target' do
@@ -100,26 +99,20 @@ module Selenium
 
       it 'notifies about log messages' do
         logs = []
-        driver.on_log_event(:console) { |log| logs.push(log) }
+        driver.on_log_event(:console) { |log| logs.push(log.args[0]) }
         driver.navigate.to url_for('javascriptPage.html')
 
-        driver.execute_script("console.log('I like cheese');")
-        sleep 0.5
         driver.execute_script('console.log(true);')
-        sleep 0.5
         driver.execute_script('console.log(null);')
-        sleep 0.5
         driver.execute_script('console.log(undefined);')
-        sleep 0.5
         driver.execute_script('console.log(document);')
-        sleep 0.5
+        driver.execute_script("console.log('I like cheese');")
 
-        expect(logs).to include(
-          an_object_having_attributes(type: :log, args: ['I like cheese']),
-          an_object_having_attributes(type: :log, args: [true]),
-          an_object_having_attributes(type: :log, args: [nil]),
-          an_object_having_attributes(type: :log, args: [{'type' => 'undefined'}])
-        )
+        wait.until { logs.include?('I like cheese') }
+
+        expect(logs).to include(true)
+        expect(logs).to include(nil)
+        expect(logs).to include({'type' => 'undefined'})
       end
 
       it 'notifies about document log messages' do
