@@ -23,26 +23,29 @@ module Selenium
   module WebDriver
     describe Element, exclusive: {bidi: false, reason: 'Not yet implemented with BiDi'} do
       it 'clicks' do
-        driver.navigate.to url_for('formPage.html')
-        expect { driver.find_element(id: 'imageButton').click }.not_to raise_error
+        open_file 'formPage.html'
+        element = wait_for_element(id: 'imageButton')
+        expect { element.click }.not_to raise_error
         reset_driver!(time: 1) if %i[safari safari_preview].include? GlobalTestEnv.browser
       end
 
       # Safari returns "click intercepted" error instead of "element click intercepted"
       it 'raises if different element receives click', except: {browser: %i[safari safari_preview]} do
-        driver.navigate.to url_for('click_tests/overlapping_elements.html')
-        expect { driver.find_element(id: 'contents').click }.to raise_error(Error::ElementClickInterceptedError)
+        open_file 'click_tests/overlapping_elements.html'
+        element = wait_for_element(id: 'contents', timeout: 10)
+        expect { element.click }.to raise_error(Error::ElementClickInterceptedError)
       end
 
       # Safari returns "click intercepted" error instead of "element click intercepted"
       it 'raises if element is partially covered', except: {browser: %i[safari safari_preview]} do
-        driver.navigate.to url_for('click_tests/overlapping_elements.html')
-        expect { driver.find_element(id: 'other_contents').click }.to raise_error(Error::ElementClickInterceptedError)
+        open_file 'click_tests/overlapping_elements.html'
+        element = wait_for_element(id: 'other_contents')
+        expect { element.click }.to raise_error(Error::ElementClickInterceptedError)
       end
 
       it 'raises if element stale' do
-        driver.navigate.to url_for('formPage.html')
-        button = driver.find_element(id: 'imageButton')
+        open_file 'formPage.html'
+        button = wait_for_element(id: 'imageButton')
         driver.navigate.refresh
 
         expect { button.click }.to raise_exception(Error::StaleElementReferenceError,
@@ -53,67 +56,68 @@ module Selenium
 
       describe '#submit' do
         it 'valid submit button' do
-          driver.navigate.to url_for('formPage.html')
-          driver.find_element(id: 'submitButton').submit
+          open_file 'formPage.html'
+          wait_for_element(id: 'submitButton').submit
 
-          sleep 0.5
+          wait_for_url('resultPage.html')
           expect(driver.title).to eq('We Arrive Here')
         end
 
         it 'any input element in form' do
-          driver.navigate.to url_for('formPage.html')
-          driver.find_element(id: 'checky').submit
+          open_file 'formPage.html'
+          wait_for_element(id: 'checky').submit
 
-          sleep 0.5
+          wait_for_url('resultPage.html')
           expect(driver.title).to eq('We Arrive Here')
         end
 
         it 'any element in form' do
-          driver.navigate.to url_for('formPage.html')
-          driver.find_element(css: 'form > p').submit
+          open_file 'formPage.html'
+          wait_for_element(css: 'form > p').submit
 
-          sleep 0.5
+          wait_for_url('resultPage.html')
           expect(driver.title).to eq('We Arrive Here')
         end
 
         it 'button with id submit' do
-          driver.navigate.to url_for('formPage.html')
-          driver.find_element(id: 'submit').submit
+          open_file 'formPage.html'
+          wait_for_element(id: 'submit').submit
 
-          sleep 0.5
+          wait_for_url('resultPage.html')
           expect(driver.title).to eq('We Arrive Here')
         end
 
         it 'button with name submit' do
-          driver.navigate.to url_for('formPage.html')
-          driver.find_element(name: 'submit').submit
+          open_file 'formPage.html'
+          wait_for_element(name: 'submit').submit
 
-          sleep 0.5
+          wait_for_url('resultPage.html')
           expect(driver.title).to eq('We Arrive Here')
         end
 
         it 'errors with button outside form' do
-          driver.navigate.to url_for('formPage.html')
-          expect { driver.find_element(name: 'SearchableText').submit }.to raise_error(Error::UnsupportedOperationError)
+          open_file 'formPage.html'
+          element = wait_for_element(name: 'SearchableText')
+          expect { element.submit }.to raise_error(Error::UnsupportedOperationError)
         end
       end
 
       it 'sends empty keys' do
-        driver.navigate.to url_for('formPage.html')
+        open_file 'formPage.html'
         element = wait_for_element(id: 'working')
         element.send_keys
         expect(element.text).to be_empty
       end
 
       it 'sends string keys' do
-        driver.navigate.to url_for('formPage.html')
+        open_file 'formPage.html'
         wait_for_element(id: 'working')
         expect { driver.find_element(id: 'working').send_keys('foo', 'bar') }.not_to raise_error
       end
 
       it 'sends key presses' do
-        driver.navigate.to url_for('javascriptPage.html')
-        key_reporter = driver.find_element(id: 'keyReporter')
+        open_file 'javascriptPage.html'
+        key_reporter = wait_for_element(id: 'keyReporter')
 
         key_reporter.send_keys('Tet', :arrow_left, 's')
         expect(key_reporter.attribute('value')).to eq('Test')
@@ -121,17 +125,17 @@ module Selenium
 
       # https://github.com/mozilla/geckodriver/issues/245
       it 'sends key presses chords', except: {browser: %i[firefox safari safari_preview]} do
-        driver.navigate.to url_for('javascriptPage.html')
-        key_reporter = driver.find_element(id: 'keyReporter')
+        open_file 'javascriptPage.html'
+        key_reporter = wait_for_element(id: 'keyReporter')
 
         key_reporter.send_keys([:shift, 'h'], 'ello')
         expect(key_reporter.attribute('value')).to eq('Hello')
       end
 
       it 'handles file uploads' do
-        driver.navigate.to url_for('formPage.html')
+        open_file 'formPage.html'
 
-        element = driver.find_element(id: 'upload')
+        element = wait_for_element(id: 'upload')
         expect(element.attribute('value')).to be_empty
 
         path = WebDriver::Platform.windows? ? WebDriver::Platform.windows_path(__FILE__) : __FILE__
@@ -142,10 +146,10 @@ module Selenium
       end
 
       describe 'properties and attributes' do
-        before { driver.navigate.to url_for('formPage.html') }
+        before { open_file 'formPage.html' }
 
         context 'when string type' do
-          let(:element) { driver.find_element(id: 'checky') }
+          let(:element) { wait_for_element(id: 'checky') }
           let(:prop_or_attr) { 'type' }
 
           it '#dom_attribute returns attribute value' do
@@ -162,7 +166,7 @@ module Selenium
         end
 
         context 'when numeric type' do
-          let(:element) { driver.find_element(id: 'withText') }
+          let(:element) { wait_for_element(id: 'withText') }
           let(:prop_or_attr) { 'rows' }
 
           it '#dom_attribute String' do
@@ -179,7 +183,7 @@ module Selenium
         end
 
         context 'with boolean type of true' do
-          let(:element) { driver.find_element(id: 'checkedchecky') }
+          let(:element) { wait_for_element(id: 'checkedchecky') }
           let(:prop_or_attr) { 'checked' }
 
           it '#dom_attribute returns String', except: {browser: :safari} do
@@ -211,7 +215,7 @@ module Selenium
         end
 
         context 'with boolean type of false' do
-          let(:element) { driver.find_element(id: 'checky') }
+          let(:element) { wait_for_element(id: 'checky') }
           let(:prop_or_attr) { 'checked' }
 
           it '#dom_attribute returns nil' do
@@ -243,7 +247,7 @@ module Selenium
         end
 
         context 'when property exists but attribute does not' do
-          let(:element) { driver.find_element(id: 'withText') }
+          let(:element) { wait_for_element(id: 'withText') }
           let(:prop_or_attr) { 'value' }
 
           it '#dom_attribute returns nil' do
@@ -270,7 +274,7 @@ module Selenium
         end
 
         context 'when attribute exists but property does not' do
-          let(:element) { driver.find_element(id: 'vsearchGadget') }
+          let(:element) { wait_for_element(id: 'vsearchGadget') }
           let(:prop_or_attr) { 'accesskey' }
 
           it '#dom_attribute returns attribute' do
@@ -287,7 +291,7 @@ module Selenium
         end
 
         context 'when neither attribute nor property exists' do
-          let(:element) { driver.find_element(id: 'checky') }
+          let(:element) { wait_for_element(id: 'checky') }
           let(:prop_or_attr) { 'nonexistent' }
 
           it '#dom_attribute returns nil' do
@@ -304,9 +308,9 @@ module Selenium
         end
 
         describe 'style' do
-          before { driver.navigate.to url_for('clickEventPage.html') }
+          before { open_file 'clickEventPage.html' }
 
-          let(:element) { driver.find_element(id: 'result') }
+          let(:element) { wait_for_element(id: 'result') }
           let(:prop_or_attr) { 'style' }
 
           it '#dom_attribute attribute with no formatting' do
@@ -327,7 +331,7 @@ module Selenium
         end
 
         describe 'incorrect casing' do
-          let(:element) { driver.find_element(id: 'checky') }
+          let(:element) { wait_for_element(id: 'checky') }
           let(:prop_or_attr) { 'nAme' }
 
           it '#dom_attribute returns correctly cased attribute' do
@@ -344,7 +348,7 @@ module Selenium
         end
 
         describe 'property attribute case difference with attribute casing' do
-          let(:element) { driver.find_element(name: 'readonly') }
+          let(:element) { wait_for_element(name: 'readonly') }
           let(:prop_or_attr) { 'readonly' }
 
           it '#dom_attribute returns a String', except: {browser: :safari} do
@@ -361,7 +365,7 @@ module Selenium
         end
 
         describe 'property attribute case difference with property casing' do
-          let(:element) { driver.find_element(name: 'readonly') }
+          let(:element) { wait_for_element(name: 'readonly') }
           let(:prop_or_attr) { 'readOnly' }
 
           it '#dom_attribute returns a String',
@@ -381,7 +385,7 @@ module Selenium
         end
 
         describe 'property attribute name difference with attribute naming' do
-          let(:element) { driver.find_element(id: 'wallace') }
+          let(:element) { wait_for_element(id: 'wallace') }
           let(:prop_or_attr) { 'class' }
 
           it '#dom_attribute returns attribute value' do
@@ -398,7 +402,7 @@ module Selenium
         end
 
         describe 'property attribute name difference with property naming' do
-          let(:element) { driver.find_element(id: 'wallace') }
+          let(:element) { wait_for_element(id: 'wallace') }
           let(:prop_or_attr) { 'className' }
 
           it '#dom_attribute returns nil' do
@@ -415,7 +419,7 @@ module Selenium
         end
 
         describe 'property attribute value difference' do
-          let(:element) { driver.find_element(tag_name: 'form') }
+          let(:element) { wait_for_element(tag_name: 'form') }
           let(:prop_or_attr) { 'action' }
 
           it '#dom_attribute returns attribute value' do
@@ -448,15 +452,16 @@ module Selenium
       end
 
       it 'clears' do
-        driver.navigate.to url_for('formPage.html')
-        expect { driver.find_element(id: 'withText').clear }.not_to raise_error
+        open_file 'formPage.html'
+        element = wait_for_element(id: 'withText')
+        expect { element.clear }.not_to raise_error
       end
 
       it 'gets and set selected' do
-        driver.navigate.to url_for('formPage.html')
+        open_file 'formPage.html'
 
-        cheese = driver.find_element(id: 'cheese')
-        peas = driver.find_element(id: 'peas')
+        cheese = wait_for_element(id: 'cheese')
+        peas = wait_for_element(id: 'peas')
 
         cheese.click
 
@@ -470,48 +475,51 @@ module Selenium
       end
 
       it 'gets enabled' do
-        driver.navigate.to url_for('formPage.html')
-        expect(driver.find_element(id: 'notWorking')).not_to be_enabled
+        open_file 'formPage.html'
+        element = wait_for_element(id: 'notWorking')
+        expect(element).not_to be_enabled
       end
 
       it 'gets text' do
-        driver.navigate.to url_for('xhtmlTest.html')
-        expect(driver.find_element(class: 'header').text).to eq('XHTML Might Be The Future')
+        open_file 'xhtmlTest.html'
+        element = wait_for_element(class: 'header')
+        expect(element.text).to eq('XHTML Might Be The Future')
       end
 
       it 'gets displayed' do
-        driver.navigate.to url_for('xhtmlTest.html')
-        expect(driver.find_element(class: 'header')).to be_displayed
+        open_file 'xhtmlTest.html'
+        element = wait_for_element(class: 'header')
+        expect(element).to be_displayed
       end
 
       describe 'size and location' do
         it 'gets current location' do
-          driver.navigate.to url_for('xhtmlTest.html')
-          loc = driver.find_element(class: 'header').location
+          open_file 'xhtmlTest.html'
+          loc = wait_for_element(class: 'header').location
 
           expect(loc.x).to be >= 1
           expect(loc.y).to be >= 1
         end
 
         it 'gets location once scrolled into view' do
-          driver.navigate.to url_for('javascriptPage.html')
-          loc = driver.find_element(id: 'keyUp').location_once_scrolled_into_view
+          open_file 'javascriptPage.html'
+          loc = wait_for_element(id: 'keyUp').location_once_scrolled_into_view
 
           expect(loc.x).to be >= 1
           expect(loc.y).to be >= 0 # can be 0 if scrolled to the top
         end
 
         it 'gets size' do
-          driver.navigate.to url_for('xhtmlTest.html')
-          size = driver.find_element(class: 'header').size
+          open_file 'xhtmlTest.html'
+          size = wait_for_element(class: 'header').size
 
           expect(size.width).to be_positive
           expect(size.height).to be_positive
         end
 
         it 'gets rect' do
-          driver.navigate.to url_for('xhtmlTest.html')
-          rect = driver.find_element(class: 'header').rect
+          open_file 'xhtmlTest.html'
+          rect = wait_for_element(class: 'header').rect
 
           expect(rect.x).to be_positive
           expect(rect.y).to be_positive
@@ -522,10 +530,10 @@ module Selenium
 
       # IE - https://github.com/SeleniumHQ/selenium/pull/4043
       it 'drags and drop', except: {browser: :ie} do
-        driver.navigate.to url_for('dragAndDropTest.html')
+        open_file 'dragAndDropTest.html'
 
-        img1 = driver.find_element(id: 'test1')
-        img2 = driver.find_element(id: 'test2')
+        img1 = wait_for_element(id: 'test1')
+        img2 = wait_for_element(id: 'test2')
 
         driver.action.drag_and_drop_by(img1, 100, 100)
               .drag_and_drop(img2, img1)
@@ -535,8 +543,8 @@ module Selenium
       end
 
       it 'gets css property' do
-        driver.navigate.to url_for('javascriptPage.html')
-        element = driver.find_element(id: 'green-parent')
+        open_file 'javascriptPage.html'
+        element = wait_for_element(id: 'green-parent')
 
         style1 = element.css_value('background-color')
         style2 = element.style('background-color') # backwards compatibility
@@ -546,10 +554,10 @@ module Selenium
       end
 
       it 'knows when two elements are equal' do
-        driver.navigate.to url_for('simpleTest.html')
+        open_file 'simpleTest.html'
 
-        body = driver.find_element(tag_name: 'body')
-        xbody = driver.find_element(xpath: '//body')
+        body = wait_for_element(tag_name: 'body')
+        xbody = wait_for_element(xpath: '//body')
         jsbody = driver.execute_script('return document.getElementsByTagName("body")[0]')
 
         expect(body).to eq(xbody)
@@ -559,7 +567,7 @@ module Selenium
       end
 
       it 'knows when element arrays are equal' do
-        driver.navigate.to url_for('simpleTest.html')
+        open_file 'simpleTest.html'
 
         tags = driver.find_elements(tag_name: 'div')
         jstags = driver.execute_script('return document.getElementsByTagName("div")')
@@ -568,7 +576,7 @@ module Selenium
       end
 
       it 'knows when two elements are not equal' do
-        driver.navigate.to url_for('simpleTest.html')
+        open_file 'simpleTest.html'
 
         elements = driver.find_elements(tag_name: 'p')
         p1 = elements.fetch(0)
@@ -579,7 +587,7 @@ module Selenium
       end
 
       it 'returns the same #hash for equal elements when found by Driver#find_element' do
-        driver.navigate.to url_for('simpleTest.html')
+        open_file 'simpleTest.html'
 
         body = driver.find_element(tag_name: 'body')
         xbody = driver.find_element(xpath: '//body')
@@ -588,7 +596,7 @@ module Selenium
       end
 
       it 'returns the same #hash for equal elements when found by Driver#find_elements' do
-        driver.navigate.to url_for('simpleTest.html')
+        open_file 'simpleTest.html'
 
         body = driver.find_elements(tag_name: 'body').fetch(0)
         xbody = driver.find_elements(xpath: '//body').fetch(0)
